==> webkit2gtk_2.44.2.orig.tar.xz: webkitgtk-2.44.2/Source/JavaScriptCore/heap/HeapProfiler.cpp <==
/*
 * Copyright (C) 2016-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#include "config.h"
#include "HeapProfiler.h"

#include "HeapSnapshot.h"
#include "VM.h"
#include <wtf/TZoneMallocInlines.h>

namespace JSC {

WTF_MAKE_TZONE_ALLOCATED_IMPL(HeapProfiler);

HeapProfiler::HeapProfiler(VM& vm)
    : m_vm(vm)
{
}

HeapProfiler::~HeapProfiler()
{
}

HeapSnapshot* HeapProfiler::mostRecentSnapshot()
{
    if (m_snapshots.isEmpty())
        return nullptr;
    return m_snapshots.last().get();
}

void HeapProfiler::appendSnapshot(std::unique_ptr<HeapSnapshot> snapshot)
{
    m_snapshots.append(WTFMove(snapshot));
}

void HeapProfiler::clearSnapshots()
{
    m_snapshots.clear();
}

void HeapProfiler::setActiveHeapAnalyzer(HeapAnalyzer* analyzer)
{
    ASSERT(!!m_activeAnalyzer != !!analyzer);
    m_activeAnalyzer = analyzer;
    m_vm.setActiveHeapAnalyzer(analyzer);
}

} // namespace JSC

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/JavaScriptCore/heap/HeapProfiler.cpp <==
/*
 * Copyright (C) 2016-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#include "config.h"
#include "HeapProfiler.h"

#include "HeapSnapshot.h"
#include "VM.h"
#include <wtf/TZoneMallocInlines.h>

namespace JSC {

WTF_MAKE_TZONE_ALLOCATED_IMPL(HeapProfiler);

HeapProfiler::HeapProfiler(VM& vm)
    : m_vm(vm)
{
}

HeapProfiler::~HeapProfiler() = default;

HeapSnapshot* HeapProfiler::mostRecentSnapshot()
{
    if (m_snapshots.isEmpty())
        return nullptr;
    return m_snapshots.last().get();
}

void HeapProfiler::appendSnapshot(std::unique_ptr<HeapSnapshot> snapshot)
{
    m_snapshots.append(WTF::move(snapshot));
}

void HeapProfiler::clearSnapshots()
{
    m_snapshots.clear();
}

void HeapProfiler::setActiveHeapAnalyzer(HeapAnalyzer* analyzer)
{
    ASSERT(!!m_activeAnalyzer != !!analyzer);
    m_activeAnalyzer = analyzer;
    m_vm.setActiveHeapAnalyzer(analyzer);
}

} // namespace JSC
